@@ -91,6 +91,9 @@
 #' \item{outlier_relative}{a logical indicating whether the threshold is an absolute 
 #' or relative value, default to FALSE (absolute value).}
 #' 
+#' \item{outlier_plot}{a logical indicating whether to plot the comparison between the 
+#' likelihoods of connection in the short run and the threshold.}
+#' 
 #' \item{n_iter_import}{Number of iterations of the first short run.}
 #' 
 #' \item{sample_every_import}{the frequency at which MCMC samples are retained for the
@@ -157,11 +160,12 @@ create_config <- function (..., data = NULL)
                    prior_a = c(0.2, 1.5), prior_b = c(0.01, 2), 
                    
                    sd_pi = 0.1, sd_a = 0.1, sd_b = 0.1, 
-
+                   
                    n_iter = 10000, sample_every = 50, 
                    
                    max_kappa = 2, find_import = TRUE, outlier_threshold = 0.05, 
-                   outlier_relative = FALSE,
+                   outlier_relative = FALSE, outlier_plot = FALSE,
+                   
                    n_iter_import = 5000, sample_every_import = 50, 
                    burnin = 1000, verbatim = FALSE)
   config <- modify_defaults(defaults, config)
@@ -393,6 +397,12 @@ create_config <- function (..., data = NULL)
   if (!is.finite(config$outlier_threshold)) {
     stop("outlier_threshold is infinite or NA")
   }
+  if (!is.logical(config$outlier_plot)) {
+    stop("outlier_plot is not a logical")
+  }
+  if (is.na(config$outlier_plot)) {
+    stop("outlier_plot is NA")
+  }
   if (!is.numeric(config$n_iter_import)) {
     stop("n_iter_import is not a numeric value")
   }
@@ -462,12 +472,17 @@ create_config <- function (..., data = NULL)
       config$init_alpha[data$import == TRUE] <- NA
       config$init_alpha[!duplicated(data$is_cluster)] <- NA
       for(X in unique(data$is_cluster)){
+        # Cases in the cluster
         cases_clust <- which(data$is_cluster == X)
+        # All genotypes in the cluster
         nb_gen <- unique(data$genotype[data$is_cluster == X & 
                                          data$genotype != "Not attributed"])
+        # Genotypes of cases that are imports
         gen_clust <- data$genotype[cases_clust][is.na(config$init_alpha[cases_clust])]
+        # Unique genotypes + all NAs
         unique_gen_clust <- gen_clust[gen_clust == "Not attributed" | 
                                         !duplicated(gen_clust)]
+        # If more genotypes than potential imports, add new import
         while(length(nb_gen) > length(unique_gen_clust)){
           config$init_alpha[data$is_cluster == X & 
                               data$genotype != "Not attributed" &
@@ -477,42 +492,52 @@ create_config <- function (..., data = NULL)
                                           !duplicated(gen_clust)]
           
         }
+        # All genotypes in non imports
         nb_gen_sec <- unique(data$genotype[data$is_cluster == X & 
                                              !is.na(config$init_alpha) &
                                              data$genotype != "Not attributed"])
+        pot_ances <- which(is.na(config$init_alpha) & data$is_cluster == X)
         count <- 1
         for(j in nb_gen_sec){
           count_gen <- count
+          notances_X_j <- which(data$is_cluster == X & 
+                                  !is.na(config$init_alpha) &
+                                  data$genotype == j)
+          
+          # If there is an ancestor from X with the same genotype before the first case
+          # then increment count_gen
           if(any(is.na(config$init_alpha) & data$is_cluster == X & 
                  data$genotype == j & 
-                 data$dates <= min(data$dates[which(data$is_cluster == X & 
-                                                   !is.na(config$init_alpha) &
-                                                   data$genotype == j)]))){
+                 data$dates <= min(data$dates[notances_X_j]))){
             count_gen <- which(gen_clust == j)[1]
           } else {
-            while(!(gen_clust[count_gen] == "Not attributed" | 
-                    gen_clust[count_gen] == j)){
+            while(count_gen < length(gen_clust) && !(gen_clust[count_gen] == j)){
               count_gen <- count_gen + 1
             }
-            if(gen_clust[count] == "Not attributed" ) count <- count_gen + 1
+            if(gen_clust[count_gen] != j){
+              count_gen <- count
+              while(count_gen < length(gen_clust) &&
+                    !(gen_clust[count_gen] == "Not attributed")){
+                count_gen <- count_gen + 1
+              }
+            }
+            if(gen_clust[count_gen] == "Not attributed") count <- count_gen + 1
           }
-          if(data$dates[which(is.na(config$init_alpha) &
-                               data$is_cluster == X)[count_gen]] >
-             min(data$dates[data$is_cluster == X & !is.na(config$init_alpha) &
-                                              data$genotype == j])){
-            new_ances <- which(data$is_cluster == X & !is.na(config$init_alpha) &
-                                             data$genotype == j)[1]
+          # If the potential import was reported before all the cases, then the first
+          # case is added as an import
+          if(data$dates[pot_ances[count_gen]] > min(data$dates[notances_X_j])){
+            new_ances <- notances_X_j[1]
             config$init_alpha[new_ances] <- NA
             config$init_alpha[data$is_cluster == X & !is.na(config$init_alpha) &
                                 data$genotype == j] <- new_ances
-          } else 
-            config$init_alpha[data$is_cluster == X & !is.na(config$init_alpha) &
-                                data$genotype == j] <- which(is.na(config$init_alpha) &
-                                                               data$is_cluster == X)[count_gen]
+          } else {
+            # Otherwise, all cases are linked to the potential import
+            config$init_alpha[notances_X_j] <- pot_ances[count_gen]
+          }
         }
         for (k in which(data$is_cluster == X &
-                         !is.na(config$init_alpha) &
-                         data$genotype == "Not attributed")){
+                        !is.na(config$init_alpha) &
+                        data$genotype == "Not attributed")){
           config$init_alpha[k] <- max(which(data$is_cluster[1:k] == X &
                                               is.na(config$init_alpha[1:k])))
         }
